aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr
diff options
context:
space:
mode:
authorJa.KooLit <jimmielovejay@gmail.com>2024-05-13 02:36:43 +0900
committerGitHub <noreply@github.com>2024-05-13 02:36:43 +0900
commit683e801de6ee2fe01513311e2bc13f695cd96486 (patch)
tree64df94cb64f5ba161761bfd64ae93658ca163f9c /config/hypr
parent35327b2814b228253464f0358f58c553ec98002b (diff)
parentea93a71cf6ac92041f00168e040cdc22882047b7 (diff)
Merge branch 'development' into main
Diffstat (limited to 'config/hypr')
-rw-r--r--config/hypr/UserConfigs/UserSettings.conf9
-rwxr-xr-xconfig/hypr/UserScripts/RofiBeats.sh84
-rwxr-xr-xconfig/hypr/UserScripts/WallpaperAutoChange.sh4
-rwxr-xr-xconfig/hypr/UserScripts/WallpaperRandom.sh6
-rwxr-xr-xconfig/hypr/UserScripts/WallpaperSelect.sh2
-rwxr-xr-xconfig/hypr/UserScripts/Weather.py12
-rw-r--r--config/hypr/hyprlock.conf20
-rwxr-xr-xconfig/hypr/initial-boot.sh19
-rwxr-xr-xconfig/hypr/scripts/DarkLight.sh28
-rwxr-xr-xconfig/hypr/scripts/GameMode.sh2
-rwxr-xr-xconfig/hypr/scripts/KeyHints.sh4
-rwxr-xr-xconfig/hypr/scripts/LockScreen.sh2
-rwxr-xr-xconfig/hypr/scripts/Refresh.sh4
-rwxr-xr-xconfig/hypr/scripts/RefreshNoWaybar.sh8
-rwxr-xr-xconfig/hypr/scripts/Sounds.sh4
-rw-r--r--config/hypr/scripts/UptimeNixOS.sh33
-rwxr-xr-xconfig/hypr/scripts/WallustSwww.sh (renamed from config/hypr/scripts/PywalSwww.sh)11
-rw-r--r--config/hypr/wallust/wallust-hyprland.conf18
18 files changed, 192 insertions, 78 deletions
diff --git a/config/hypr/UserConfigs/UserSettings.conf b/config/hypr/UserConfigs/UserSettings.conf
index da8ec4ed..b3193e49 100644
--- a/config/hypr/UserConfigs/UserSettings.conf
+++ b/config/hypr/UserConfigs/UserSettings.conf
@@ -4,8 +4,9 @@
# refer to Hyprland wiki for more info https://wiki.hyprland.org/Configuring/Variables
-# Sourcing colors generated by pywal
-source = $HOME/.cache/wal/colors-hyprland
+# Sourcing colors generated by wallust
+source = $HOME/.config/hypr/wallust/wallust-hyprland.conf
+
# blurls = waybar
# blurls = rofi
@@ -29,7 +30,7 @@ general {
border_size = 2
resize_on_border = true
- col.active_border = $color0 $color2 $color4 $color6 $color8 90deg
+ col.active_border = $color0 $color2 $color9 $color12 $color15 90deg
col.inactive_border = $backgroundCol
layout = master
@@ -57,7 +58,7 @@ decoration {
drop_shadow=true
shadow_range=6
shadow_render_power = 1
- col.shadow = $color2
+ col.shadow = $color12
col.shadow_inactive = 0x50000000
blur {
diff --git a/config/hypr/UserScripts/RofiBeats.sh b/config/hypr/UserScripts/RofiBeats.sh
index e3c79587..76634a1a 100755
--- a/config/hypr/UserScripts/RofiBeats.sh
+++ b/config/hypr/UserScripts/RofiBeats.sh
@@ -1,13 +1,14 @@
#!/bin/bash
+# Directory music folder
+mDIR="$HOME/Music/"
+
# Directory for icons
iDIR="$HOME/.config/swaync/icons"
-# Note: You can add more options below with the following format:
-# ["TITLE"]="link"
-
-# Define menu options as an associative array
-declare -A menu_options=(
+# Online Stations
+declare -A online_music=(
+ ["AfroBeatz 2024 🎧"]="https://www.youtube.com/watch?v=7uB-Eh9XVZQ"
["Lofi Girl ☕️🎶"]="https://play.streamafrica.net/lofiradio"
["Easy Rock 96.3 FM 📻🎶"]="https://radio-stations-philippines.com/easy-rock"
["Wish 107.5 FM 📻🎶"]="https://radio-stations-philippines.com/dwnu-1075-wish"
@@ -21,30 +22,79 @@ declare -A menu_options=(
["Korean Drama OST 📻🎶"]="https://youtube.com/playlist?list=PLUge_o9AIFp4HuA-A3e3ZqENh63LuRRlQ"
)
+# Local Music
+# Populate local_music array with files from music directory and subdirectories
+populate_local_music() {
+ local_music=()
+ filenames=()
+ while IFS= read -r file; do
+ local_music+=("$file")
+ filenames+=("$(basename "$file")")
+ done < <(find "$mDIR" -type f \( -iname "*.mp3" -o -iname "*.flac" -o -iname "*.wav" -o -iname "*.ogg" \))
+}
+
# Function for displaying notifications
notification() {
- notify-send -u normal -i "$iDIR/music.png" "Playing now: $@"
+ notify-send -u normal -i "$iDIR/music.png" "Playing: $@"
}
-# Main function
-main() {
- choice=$(printf "%s\n" "${!menu_options[@]}" | rofi -i -dmenu -config ~/.config/rofi/config-rofi-Beats.rasi -p "")
+# Main function for playing local music
+play_local_music() {
+ populate_local_music
+
+ # Prompt the user to select a song
+ choice=$(printf "%s\n" "${filenames[@]}" | rofi -i -dmenu -config ~/.config/rofi/config-rofi-Beats.rasi -p "Local Music")
if [ -z "$choice" ]; then
exit 1
fi
- link="${menu_options[$choice]}"
+ # Find the corresponding file path based on user's choice
+ for (( i=0; i<"${#filenames[@]}"; i++ )); do
+ if [ "${filenames[$i]}" = "$choice" ]; then
+ file="${local_music[$i]}"
+ break
+ fi
+ done
notification "$choice"
-
- # Check if the link is a playlist
- if [[ $link == *playlist* ]]; then
- mpv --shuffle --vid=no "$link"
- else
- mpv "$link"
+
+ # Play the selected local music file using mpv
+ mpv --shuffle --vid=no "$file"
+}
+
+
+# Main function for playing online music
+play_online_music() {
+ choice=$(printf "%s\n" "${!online_music[@]}" | rofi -i -dmenu -config ~/.config/rofi/config-rofi-Beats.rasi -p "Online Music")
+
+ if [ -z "$choice" ]; then
+ exit 1
fi
+
+ link="${online_music[$choice]}"
+
+ notification "$choice"
+
+ # Play the selected online music using mpv
+ mpv --shuffle --vid=no "$link"
}
# Check if an online music process is running and send a notification, otherwise run the main function
-pkill mpv && notify-send -u low -i "$iDIR/music.png" "Online Music stopped" || main
+pkill mpv && notify-send -u low -i "$iDIR/music.png" "Online Music stopped" || {
+
+# Prompt the user to choose between local and online music
+user_choice=$(printf "Play from Music Folder\nPlay from Online Stations" | rofi -dmenu -config ~/.config/rofi/config-rofi-Beats-menu.rasi -p "Select music source")
+
+ case "$user_choice" in
+ "Play from Music Folder")
+ play_local_music
+ ;;
+ "Play from Online Stations")
+ play_online_music
+ ;;
+ *)
+ echo "Invalid choice"
+ ;;
+ esac
+}
diff --git a/config/hypr/UserScripts/WallpaperAutoChange.sh b/config/hypr/UserScripts/WallpaperAutoChange.sh
index 9e0e1cbe..f54620bb 100755
--- a/config/hypr/UserScripts/WallpaperAutoChange.sh
+++ b/config/hypr/UserScripts/WallpaperAutoChange.sh
@@ -7,7 +7,7 @@
#
# NOTE: this script uses bash (not POSIX shell) for the RANDOM variable
-pywal_refresh=$HOME/.config/hypr/scripts/RefreshNoWaybar.sh
+wallust_refresh=$HOME/.config/hypr/scripts/RefreshNoWaybar.sh
focused_monitor=$(hyprctl monitors | awk '/^Monitor/{name=$2} /focused: yes/{print name}')
@@ -32,7 +32,7 @@ while true; do
| sort -n | cut -d':' -f2- \
| while read -r img; do
swww img -o $focused_monitor "$img"
- $pywal_refresh
+ $wallust_refresh
sleep $INTERVAL
done
diff --git a/config/hypr/UserScripts/WallpaperRandom.sh b/config/hypr/UserScripts/WallpaperRandom.sh
index 52fc819d..050c10c3 100755
--- a/config/hypr/UserScripts/WallpaperRandom.sh
+++ b/config/hypr/UserScripts/WallpaperRandom.sh
@@ -5,6 +5,8 @@
wallDIR="$HOME/Pictures/wallpapers"
scriptsDir="$HOME/.config/hypr/scripts"
+focused_monitor=$(hyprctl monitors | awk '/^Monitor/{name=$2} /focused: yes/{print name}')
+
PICS=($(find ${wallDIR} -type f \( -name "*.jpg" -o -name "*.jpeg" -o -name "*.png" -o -name "*.gif" \)))
RANDOMPICS=${PICS[ $RANDOM % ${#PICS[@]} ]}
@@ -17,10 +19,10 @@ BEZIER=".43,1.19,1,.4"
SWWW_PARAMS="--transition-fps $FPS --transition-type $TYPE --transition-duration $DURATION --transition-bezier $BEZIER"
-swww query || swww-daemon --format xrgb && swww img ${RANDOMPICS} $SWWW_PARAMS
+swww query || swww-daemon --format xrgb && swww img -o $focused_monitor ${RANDOMPICS} $SWWW_PARAMS
-${scriptsDir}/PywalSwww.sh
+${scriptsDir}/WallustSwww.sh
sleep 1
${scriptsDir}/Refresh.sh
diff --git a/config/hypr/UserScripts/WallpaperSelect.sh b/config/hypr/UserScripts/WallpaperSelect.sh
index 2616014d..9a087c7d 100755
--- a/config/hypr/UserScripts/WallpaperSelect.sh
+++ b/config/hypr/UserScripts/WallpaperSelect.sh
@@ -85,6 +85,6 @@ fi
main
sleep 0.5
-${SCRIPTSDIR}/PywalSwww.sh
+${SCRIPTSDIR}/WallustSwww.sh
sleep 0.2
${SCRIPTSDIR}/Refresh.sh
diff --git a/config/hypr/UserScripts/Weather.py b/config/hypr/UserScripts/Weather.py
index 046dbcd3..5cd11a66 100755
--- a/config/hypr/UserScripts/Weather.py
+++ b/config/hypr/UserScripts/Weather.py
@@ -76,7 +76,7 @@ temp_min_max = f" {temp_min}\t\t {temp_max}"
# wind speed
wind_speed = html_data("span[data-testid='Wind']").text().split("\n")[1]
-wind_text = f"煮 {wind_speed}"
+wind_text = f" {wind_speed}"
# print(wind_text)
# humidity
@@ -123,14 +123,14 @@ out_data = {
}
print(json.dumps(out_data))
-simple_weather =f"{icon} {status}\n" + \
+simple_weather =f"{icon} {status}\n" + \
f" {temp} ({temp_feel_text})\n" + \
- f"{wind_text}\n" + \
- f"{humidity_text}\n" + \
- f"{visbility_text} AQI {air_quality_index}\n"
+ f"{wind_text} \n" + \
+ f"{humidity_text} \n" + \
+ f"{visbility_text} AQI{air_quality_index}\n"
try:
with open(os.path.expanduser("~/.cache/.weather_cache"), "w") as file:
file.write(simple_weather)
except:
- pass \ No newline at end of file
+ pass
diff --git a/config/hypr/hyprlock.conf b/config/hypr/hyprlock.conf
index 38c927a0..eec6d31f 100644
--- a/config/hypr/hyprlock.conf
+++ b/config/hypr/hyprlock.conf
@@ -2,7 +2,9 @@
# Hyprlock
# Original config submitted by https://github.com/SherLock707
-source = $HOME/.cache/wal/colors-hyprland
+# Sourcing colors generated by wallust
+source = $HOME/.config/hypr/wallust/wallust-hyprland.conf
+$Scripts = $HOME/.config/hypr/scripts
general {
grace = 1
@@ -33,7 +35,7 @@ input-field {
dots_center = true
outer_color = $color1
inner_color = $color0
- font_color = $color7
+ font_color = $color12
fade_on_empty = true
placeholder_text = <i>Password...</i> # Text rendered in the input box when it's empty.
hide_input = false
@@ -47,7 +49,7 @@ input-field {
label {
monitor =
text = cmd[update:18000000] echo "<b> "$(date +'%A, %-d %B %Y')" </b>"
- color = $color1
+ color = $color9
font_size = 34
font_family = JetBrains Mono Nerd Font 10
@@ -60,7 +62,7 @@ label {
label {
monitor =
text = cmd[update:18000000] echo "<b> "$(date +'Week %U')" </b>"
- color = $color7
+ color = $color5
font_size = 24
font_family = JetBrains Mono Nerd Font 10
position = 0, -250
@@ -73,7 +75,7 @@ label {
monitor =
# text = cmd[update:1000] echo "<b><big> $(date +"%I:%M:%S %p") </big></b>" # AM/PM
text = cmd[update:1000] echo "<b><big> $(date +"%H:%M:%S") </big></b>" # 24H
- color = $color7
+ color = $color15
font_size = 94
font_family = JetBrains Mono Nerd Font 10
@@ -86,7 +88,7 @@ text = cmd[update:1000] echo "<b><big> $(date +"%H:%M:%S") </big></b>" # 24H
label {
monitor =
text =  $USER
- color = $color7
+ color = $color9
font_size = 18
font_family = Inter Display Medium
@@ -98,7 +100,7 @@ label {
# uptime
label {
monitor =
- text = cmd[update:60000] echo "<b> "$(uptime -p)" </b>"
+ text = cmd[update:60000] echo "<b> "$(uptime -p || $Scripts/UptimeNixOS.sh)" </b>"
color = $color12
font_size = 24
font_family = JetBrains Mono Nerd Font 10
@@ -111,7 +113,7 @@ label {
label {
monitor =
text = cmd[update:3600000] [ -f ~/.cache/.weather_cache ] && cat ~/.cache/.weather_cache
- color = $color10
+ color = $color12
font_size = 24
font_family = JetBrains Mono Nerd Font 10
position = 50, 0
@@ -126,7 +128,7 @@ image {
size = 230
rounding = -1
border_size = 4
- border_color = $color2
+ border_color = $color1
rotate = 0
reload_time = -1
position = 0, 300
diff --git a/config/hypr/scripts/DarkLight.sh b/config/hypr/scripts/DarkLight.sh
index f9d2a933..e6f212f6 100755
--- a/config/hypr/scripts/DarkLight.sh
+++ b/config/hypr/scripts/DarkLight.sh
@@ -12,9 +12,13 @@ swaync_style="$HOME/.config/swaync/style.css"
ags_style="$HOME/.config/ags/user/style.css"
SCRIPTSDIR="$HOME/.config/hypr/scripts"
notif="$HOME/.config/swaync/images/bell.png"
-dark_rofi_pywal="$HOME/.cache/wal/colors-rofi-dark.rasi"
-light_rofi_pywal="$HOME/.cache/wal/colors-rofi-light.rasi"
+wallust_rofi="$HOME/.config/wallust/templates/colors-rofi.rasi"
+wallust_config="$HOME/.config/wallust/wallust.toml"
+pallete_dark="dark16"
+pallete_light="light16"
+
+# kill swaybg if running
pkill swaybg
# Initialize swww if needed
@@ -45,6 +49,13 @@ notify_user() {
notify-send -u low -i "$notif" "Switching to $1 mode"
}
+# Use sed to replace the palette setting in the wallust config file
+if [ "$next_mode" = "Dark" ]; then
+ sed -i 's/^palette = .*/palette = "'"$pallete_dark"'"/' "$wallust_config"
+else
+ sed -i 's/^palette = .*/palette = "'"$pallete_light"'"/' "$wallust_config"
+fi
+
# Function to set Waybar style
set_waybar_style() {
theme="$1"
@@ -108,17 +119,19 @@ else
qt6ct_color_scheme="$HOME/.config/qt6ct/colors/Catppuccin-Latte.conf"
fi
-kvantummanager --set "$kvantum_theme"
sed -i "s|^color_scheme_path=.*$|color_scheme_path=$qt5ct_color_scheme|" "$HOME/.config/qt5ct/qt5ct.conf"
sed -i "s|^color_scheme_path=.*$|color_scheme_path=$qt6ct_color_scheme|" "$HOME/.config/qt6ct/qt6ct.conf"
+kvantummanager --set "$kvantum_theme"
-# Set Rofi Themes
+
+# set the rofi color for background
if [ "$next_mode" = "Dark" ]; then
- ln -sf "$dark_rofi_pywal" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi"
+ sed -i '24s/.*/background: rgba(0,0,0,0.7);/' $wallust_rofi
else
- ln -sf "$light_rofi_pywal" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi"
+ sed -i '24s/.*/background: rgba(255,255,255,0.9);/' $wallust_rofi
fi
+
# GTK themes and icons switching
set_custom_gtk_theme() {
mode=$1
@@ -201,10 +214,11 @@ update_theme_mode
sleep 0.5
# Run remaining scripts
-${SCRIPTSDIR}/PywalSwww.sh
+${SCRIPTSDIR}/WallustSwww.sh
sleep 1
${SCRIPTSDIR}/Refresh.sh
+sleep 0.3
# Display notifications for theme and icon changes
notify-send -u normal -i "$notif" "Themes in $next_mode Mode"
diff --git a/config/hypr/scripts/GameMode.sh b/config/hypr/scripts/GameMode.sh
index 37afe066..5ad268ca 100755
--- a/config/hypr/scripts/GameMode.sh
+++ b/config/hypr/scripts/GameMode.sh
@@ -22,7 +22,7 @@ if [ "$HYPRGAMEMODE" = 1 ] ; then
else
swww-daemon && swww img "$HOME/.config/rofi/.current_wallpaper" &
sleep 0.1
- ${SCRIPTSDIR}/PywalSwww.sh
+ ${SCRIPTSDIR}/WallustSwww.sh
sleep 0.5
${SCRIPTSDIR}/Refresh.sh
notify-send -e -u normal -i "$notif" "gamemode disabled. All animations normal"
diff --git a/config/hypr/scripts/KeyHints.sh b/config/hypr/scripts/KeyHints.sh
index d45f2e7e..f7450217 100755
--- a/config/hypr/scripts/KeyHints.sh
+++ b/config/hypr/scripts/KeyHints.sh
@@ -40,7 +40,7 @@ yad --width=$dynamic_width --height=$dynamic_height \
"ESC" "close this app" "" "=" "SUPER KEY (Windows Key)" "(SUPER KEY)" \
" enter" "Terminal" "(kitty)" \
" SHIFT enter" "DropDown Terminal" "(kitty-pyprland)" \
-" D" "App Launcher" "(rofi)" \
+" D" "App Launcher" "(rofi-wayland)" \
" T" "Open File Manager" "(Thunar)" \
" S" "Google Search" "(rofi)" \
" Q" "close active window" "(not kill)" \
@@ -59,7 +59,7 @@ yad --width=$dynamic_width --height=$dynamic_height \
" Shift S" "screenshot region" "(swappy)" \
"ALT Print" "Screenshot active window" "active window only" \
"CTRL ALT P" "power-menu" "(wlogout)" \
-"CTRL ALT L" "screen lock" "(swaylock)" \
+"CTRL ALT L" "screen lock" "(hyprlock)" \
"CTRL ALT Del" "Hyprland Exit" "(SAVE YOUR WORK!!!)" \
" F" "Fullscreen" "Toggles to full screen" \
" ALT L" "Toggle Dwindle | Master Layout" "Hyprland Layout" \
diff --git a/config/hypr/scripts/LockScreen.sh b/config/hypr/scripts/LockScreen.sh
index 56d496a5..ce2320ab 100755
--- a/config/hypr/scripts/LockScreen.sh
+++ b/config/hypr/scripts/LockScreen.sh
@@ -2,4 +2,4 @@
# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ ##
# For Hyprlock
-hyprlock -q \ No newline at end of file
+hyprlock -q --immediate \ No newline at end of file
diff --git a/config/hypr/scripts/Refresh.sh b/config/hypr/scripts/Refresh.sh
index aeae77d1..42e70896 100755
--- a/config/hypr/scripts/Refresh.sh
+++ b/config/hypr/scripts/Refresh.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ ##
-# Scripts for refreshing ags waybar, rofi, swaync, pywal colors
+# Scripts for refreshing ags waybar, rofi, swaync, wallust
SCRIPTSDIR=$HOME/.config/hypr/scripts
UserScripts=$HOME/.config/hypr/UserScripts
@@ -42,7 +42,5 @@ if file_exists "${UserScripts}/RainbowBorders.sh"; then
${UserScripts}/RainbowBorders.sh &
fi
-# for cava-pywal (note, need to manually restart cava once wallpaper changes)
-ln -sf "$HOME/.cache/wal/cava-colors" "$HOME/.config/cava/config" || true
exit 0 \ No newline at end of file
diff --git a/config/hypr/scripts/RefreshNoWaybar.sh b/config/hypr/scripts/RefreshNoWaybar.sh
index 42d67adc..70a4aeb3 100755
--- a/config/hypr/scripts/RefreshNoWaybar.sh
+++ b/config/hypr/scripts/RefreshNoWaybar.sh
@@ -3,7 +3,7 @@
# Modified version of Refresh but no waybar refresh
# Used by automatic wallpaper change
-# Modified inorder to refresh rofi background, Pywal, SwayNC
+# Modified inorder to refresh rofi background, Wallust, SwayNC
SCRIPTSDIR=$HOME/.config/hypr/scripts
UserScripts=$HOME/.config/hypr/UserScripts
@@ -28,8 +28,8 @@ done
# quit ags
ags -q
-# Pywal refresh
-${SCRIPTSDIR}/PywalSwww.sh &
+# Wallust refresh
+${SCRIPTSDIR}/WallustSwww.sh &
# Relaunching rainbow borders if the script exists
sleep 1
@@ -37,7 +37,5 @@ if file_exists "${UserScripts}/RainbowBorders.sh"; then
${UserScripts}/RainbowBorders.sh &
fi
-# for cava-pywal (note, need to manually restart cava once wallpaper changes)
-ln -sf "$HOME/.cache/wal/cava-colors" "$HOME/.config/cava/config" || true
exit 0 \ No newline at end of file
diff --git a/config/hypr/scripts/Sounds.sh b/config/hypr/scripts/Sounds.sh
index a749114c..e19feea4 100755
--- a/config/hypr/scripts/Sounds.sh
+++ b/config/hypr/scripts/Sounds.sh
@@ -67,4 +67,6 @@ if ! test -f "$sound_file"; then
fi
fi
fi
-pw-play "$sound_file" \ No newline at end of file
+
+# pipewire priority, fallback pulseaudio
+pw-play "$sound_file" || pa-play "$sound_file" \ No newline at end of file
diff --git a/config/hypr/scripts/UptimeNixOS.sh b/config/hypr/scripts/UptimeNixOS.sh
new file mode 100644
index 00000000..654ae2c8
--- /dev/null
+++ b/config/hypr/scripts/UptimeNixOS.sh
@@ -0,0 +1,33 @@
+#!/usr/bin/env bash
+# Script parses /proc/uptime to get the system uptime
+# and prints it in a human-readable format
+# This is a workaround for system where `uptime` command is taken from coreutils
+# where `uptime -p` is not supported
+
+if [[ -r /proc/uptime ]]; then
+ s=$(< /proc/uptime)
+ s=${s/.*}
+else
+ echo "Error UptimeNixOS.sh: Uptime could not be determined." >&2
+ exit 1
+fi
+
+d="$((s / 60 / 60 / 24)) days"
+h="$((s / 60 / 60 % 24)) hours"
+m="$((s / 60 % 60)) minutes"
+
+# Remove plural if < 2.
+((${d/ *} == 1)) && d=${d/s}
+((${h/ *} == 1)) && h=${h/s}
+((${m/ *} == 1)) && m=${m/s}
+
+# Hide empty fields.
+((${d/ *} == 0)) && unset d
+((${h/ *} == 0)) && unset h
+((${m/ *} == 0)) && unset m
+
+uptime=${d:+$d, }${h:+$h, }$m
+uptime=${uptime%', '}
+uptime=${uptime:-$s seconds}
+
+echo "up $uptime"
diff --git a/config/hypr/wallust/wallust-hyprland.conf b/config/hypr/wallust/wallust-hyprland.conf
new file mode 100644
index 00000000..00488854
--- /dev/null
+++ b/config/hypr/wallust/wallust-hyprland.conf
@@ -0,0 +1,18 @@
+$background = rgb(010102)
+$foreground = rgb(E2FECE)
+$color0 = rgb(010102)
+$color1 = rgb(595213)
+$color2 = rgb(9E2517)
+$color3 = rgb(0E714C)
+$color4 = rgb(08AC75)
+$color5 = rgb(08BCB1)
+$color6 = rgb(81BC57)
+$color7 = rgb(CDF5B1)
+$color8 = rgb(8FAB7C)
+$color9 = rgb(776D19)
+$color10 = rgb(D3311F)
+$color11 = rgb(129766)
+$color12 = rgb(0AE59C)
+$color13 = rgb(0AFAEC)
+$color14 = rgb(ACFB74)
+$color15 = rgb(CDF5B1)
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage
diff --git a/config/hypr/initial-boot.sh b/config/hypr/initial-boot.sh
index f5fe66d7..162ad65f 100755
--- a/config/hypr/initial-boot.sh
+++ b/config/hypr/initial-boot.sh
@@ -7,8 +7,8 @@
# Variables
scriptsDir=$HOME/.config/hypr/scripts
-wallpaper=$HOME/Pictures/wallpapers/Lofi-Urban-Nightscape.png
-waybar_style="$HOME/.config/waybar/style/[Pywal] Chroma Tally.css"
+wallpaper=$HOME/Pictures/wallpapers/Fantasy-Waterfall.png
+waybar_style="$HOME/.config/waybar/style/[Dark] Latte-Wallust combined.css"
kvantum_theme="Catppuccin-Mocha"
swww="swww img"
@@ -16,21 +16,18 @@ effect="--transition-bezier .43,1.19,1,.4 --transition-fps 30 --transition-type
# Check if a marker file exists.
if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
-
- # Initialize pywal and wallpaper
+ sleep 1
+ # Initialize wallust and wallpaper
if [ -f "$wallpaper" ]; then
- wal -i $wallpaper -s -t > /dev/null
+ wallust run -s $wallpaper > /dev/null
swww query || swww-daemon && $swww $wallpaper $effect
- "$scriptsDir/PywalSwww.sh" > /dev/null 2>&1 &
+ "$scriptsDir/WallustSwww.sh" > /dev/null 2>&1 &
fi
- # Initial symlink for Pywal Dark and Light for Rofi Themes
- ln -sf "$HOME/.cache/wal/colors-rofi-dark.rasi" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi" > /dev/null 2>&1 &
-
# initiate GTK dark mode and apply icon and cursor theme
gsettings set org.gnome.desktop.interface color-scheme prefer-dark > /dev/null 2>&1 &
- gsettings set org.gnome.desktop.interface gtk-theme Tokyonight-Dark-BL-LB > /dev/null 2>&1 &
- gsettings set org.gnome.desktop.interface icon-theme Tokyonight-Dark > /dev/null 2>&1 &
+ gsettings set org.gnome.desktop.interface gtk-theme Tokyonight-Dark-Moon-BL-LB > /dev/null 2>&1 &
+ gsettings set org.gnome.desktop.interface icon-theme Flat-Remix-Blue-Dark > /dev/null 2>&1 &
gsettings set org.gnome.desktop.interface cursor-theme Bibata-Modern-Ice > /dev/null 2>&1 &
gsettings set org.gnome.desktop.interface cursor-size 24 > /dev/null 2>&1 &
diff --git a/config/hypr/scripts/PywalSwww.sh b/config/hypr/scripts/WallustSwww.sh
index 9f7b15b5..2a711028 100755
--- a/config/hypr/scripts/PywalSwww.sh
+++ b/config/hypr/scripts/WallustSwww.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ ##
# Pywal Colors for current wallpaper
# Define the path to the swww cache directory
cache_dir="$HOME/.cache/swww/"
@@ -30,9 +30,8 @@ fi
# Check the flag before executing further commands
if [ "$ln_success" = true ]; then
- # execute pywal
- # wal -i "$wallpaper_path"
- echo 'about to execute wal'
- # execute pywal skipping tty and terminal changes
- wal -i "$wallpaper_path" -s -t -n -e &
+ # execute wallust
+ echo 'about to execute wallust'
+ # execute wallust skipping tty and terminal changes
+ wallust run "$wallpaper_path" -s &
fi
@@ -1,6 +1,6 @@
#!/bin/bash
# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ ##
-# Pywal Colors for current wallpaper
+# Wallust Colors for current wallpaper
# Define the path to the swww cache directory
cache_dir="$HOME/.cache/swww/"